From admin@WBIw009.westbend.net  Tue Feb 18 13:16:37 2003
Return-Path: <admin@WBIw009.westbend.net>
Received: from mx1.FreeBSD.org (mx1.freebsd.org [216.136.204.125])
	by hub.freebsd.org (Postfix) with ESMTP id 0615337B401
	for <FreeBSD-gnats-submit@freebsd.org>; Tue, 18 Feb 2003 13:16:37 -0800 (PST)
Received: from mail.westbend.net (ns1.westbend.net [216.47.253.3])
	by mx1.FreeBSD.org (Postfix) with ESMTP id 8404E43FA3
	for <FreeBSD-gnats-submit@freebsd.org>; Tue, 18 Feb 2003 13:16:35 -0800 (PST)
	(envelope-from admin@WBIw009.westbend.net)
Received: from WBIw009.westbend.net (wbiw009 [216.47.253.29])
	by mail.westbend.net (8.12.6/8.12.6) with ESMTP id h1ILGVSG058669
	for <FreeBSD-gnats-submit@freebsd.org>; Tue, 18 Feb 2003 15:16:31 -0600 (CST)
	(envelope-from admin@WBIw009.westbend.net)
Received: from WBIw009.westbend.net (localhost [127.0.0.1])
	by WBIw009.westbend.net (8.12.6/8.12.6) with ESMTP id h1ILGTvY077934
	for <FreeBSD-gnats-submit@freebsd.org>; Tue, 18 Feb 2003 15:16:30 -0600 (CST)
	(envelope-from admin@WBIw009.westbend.net)
Received: (from root@localhost)
	by WBIw009.westbend.net (8.12.7/8.12.6/Submit) id h1ILGSDV077933;
	Tue, 18 Feb 2003 15:16:28 -0600 (CST)
Message-Id: <200302182116.h1ILGSDV077933@WBIw009.westbend.net>
Date: Tue, 18 Feb 2003 15:16:28 -0600 (CST)
From: "Scot W. Hetzel" <hetzels@westbend.net>
Reply-To: "Scot W. Hetzel" <hetzels@westbend.net>
To: FreeBSD-gnats-submit@freebsd.org
Cc:
Subject: security/cyrus-sasl: Bento fails to build libkerberos + Upgrade
X-Send-Pr-Version: 3.113
X-GNATS-Notify:

>Number:         48442
>Category:       ports
>Synopsis:       security/cyrus-sasl: Bento fails to build libkerberos + Upgrade
>Confidential:   no
>Severity:       non-critical
>Priority:       low
>Responsible:    edwin
>State:          closed
>Quarter:        
>Keywords:       
>Date-Required:  
>Class:          maintainer-update
>Submitter-Id:   current-users
>Arrival-Date:   Tue Feb 18 13:20:06 PST 2003
>Closed-Date:    Wed Feb 26 03:31:03 PST 2003
>Last-Modified:  Thu Apr 17 11:00:33 PDT 2003
>Originator:     Scot W. Hetzel
>Release:        FreeBSD 4.7-STABLE i386
>Organization:
West Bend Internet
>Environment:
System: FreeBSD WBIw009.westbend.net 4.7-STABLE FreeBSD 4.7-STABLE #5: Wed Jan 15 11:31:34 CST 2003 root@WBIw009.westbend.net:/usr/obj/usr/src/src4/sys/GENERIC-SMP i386


>Description:
	Bento fails to proberly package the port on -CURRENT due to
	-CURRENT no longer has libdes.* as the des functions have been
	moved to the libcrypto.* library.

>How-To-Repeat:
	Try to build the port on -CURRENT with /usr/lib/libkrb.* libraries
	installed.  During the configure phase the DES functions will not
	be detected, and disable the KERBEROS_V4 mech.  Then it will fail
	during package creation due to missing libkerberos4.* libraries.

>Fix:
	The attached patch corrects the above problem, as well as upgrades
	the port to 1.5.28.

	Changed Files:
	    Makefile
	    distinfo
	    pkg-deinstall
	    pkg-install
	    pkg-plist
	    files/patch-ab
	    patch-saslauthd::Makefile.am
	    files/pwcheck.sh
	    files/saslauthd.sh
	    scripts/configure.sasl

	New Files:
	    files/cyrus_sasl1

	Removed Files:
	    files/patch-plugins::gssapi.c

Index: Makefile
===================================================================
RCS file: /home/ncvs/ports/security/cyrus-sasl/Makefile,v
retrieving revision 1.47
diff -u -r1.47 Makefile
--- Makefile	1 Sep 2002 16:38:33 -0000	1.47
+++ Makefile	31 Oct 2002 16:24:50 -0000
@@ -6,22 +6,24 @@
 #
 
 PORTNAME=	cyrus-sasl
-PORTVERSION=	1.5.27
-PORTREVISION=	7
+PORTVERSION=	1.5.28
+PORTREVISION=	0
 CATEGORIES=	security ipv6
 MASTER_SITES=	ftp://ftp.andrew.cmu.edu/pub/cyrus-mail/%SUBDIR%/ \
-		http://www.surf.org.uk/downloads/ \
 		ftp://ftp.westbend.net/pub/cyrus-mail/%SUBDIR%/ \
-		${MASTER_SITE_SOURCEFORGE} \
-		ftp://ftp.hanse.de/sites/transit/mirror/ftp.andrew.cmu.edu/pub/cyrus-mail/
-MASTER_SITE_SUBDIR=	. OLD-VERSIONS/sasl cyrus-utils
+		ftp://ftp.hanse.de/sites/transit/mirror/ftp.andrew.cmu.edu/pub/cyrus-mail/ \
+		http://www.surf.org.uk/downloads/:ldap_mysql \
+		ftp://ftp.westbend.net/pub/cyrus-mail/%SUBDIR%/:ldap_mysql \
+		${MASTER_SITE_SOURCEFORGE:S/$/:ldap_mysql/} \
+
+MASTER_SITE_SUBDIR=	. OLD-VERSIONS/sasl cyrus-utils:ldap_mysql
 
 DISTFILES=	${DISTNAME}${EXTRACT_SUFX} \
-		sasl-${PORTVERSION}-ldap-ssl-filter-mysql-patch4.tgz
+		sasl-${PORTVERSION}-ldap-ssl-filter-mysql-patch.tgz:ldap_mysql
 
-PATCH_SITES=	ftp://ftp.westbend.net/pub/cyrus-mail/contrib/ \
+PATCH_SITES=	ftp://ftp.westbend.net/pub/cyrus-mail/contrib/:apop \
 		http://www.imasy.or.jp/~ume/ipv6/
-PATCHFILES=	sasl_apop_patch.gz \
+PATCHFILES=	sasl_apop_patch.gz:apop \
 		${DISTNAME}-ipv6-${IPV6_VER}.diff.gz
 
 MAINTAINER=	hetzels@westbend.net
@@ -130,10 +132,16 @@
 # Fix pkg-{install/deinstall/messages}
 post-patch:
 	@${SED} -e "s;%%SASLDB%%;${SASLDB_NAME};g" \
+		-e "s;%%PWCHECK%%;${PWCHECK};g" \
+		-e "s;%%ENABLE_PWCHECK%%;${ENABLE_PWCHECK};g" \
 		-e "s;%%PWCHECK_METHOD%%;${PWCHECK_METHOD};g" \
+		-e "s;%%ENABLE_SASLAUTHD%%;${ENABLE_SASLAUTHD};g" \
 		${.CURDIR}/pkg-install > ${PKGINSTALL}
 	@${SED} -e "s;%%SASLDB%%;${SASLDB_NAME};g" \
+		-e "s;%%PWCHECK%%;${PWCHECK};g" \
+		-e "s;%%ENABLE_PWCHECK%%;${ENABLE_PWCHECK};g" \
 		-e "s;%%PWCHECK_METHOD%%;${PWCHECK_METHOD};g" \
+		-e "s;%%ENABLE_SASLAUTHD%%;${ENABLE_SASLAUTHD};g" \
 		${.CURDIR}/pkg-deinstall > ${PKGDEINSTALL}
 	@${SED} -e "s;%%PWCHECK_METHOD%%;${PWCHECK_METHOD};g" \
 		-e "s;%%PREFIX%%;${PREFIX};g" \
@@ -161,16 +169,19 @@
 	fi
 
 post-install:
-	@${SED} -e "s;%%PREFIX%%;${PREFIX};g" ${PWCHECK_SUB} \
-		${FILESDIR}/pwcheck.sh > ${PREFIX}/etc/rc.d/pwcheck.sh
 	@${MKDIR} ${EXAMPLESDIR}
 	@${SED} -e 's;%%PREFIX%%;${PREFIX};g' \
 		${FILESDIR}/cyrus.pam > ${EXAMPLESDIR}/cyrus.pam
-	@${CHMOD} 755 ${PREFIX}/etc/rc.d/pwcheck.sh
-	${INSTALL} -d -m 770 -o cyrus -g cyrus /var/pwcheck
-	@${SED} -e "s;%%PREFIX%%;${PREFIX};g" ${SASLAUTHD_SUB} \
+	@${SED} ${RC_SCRIPTS_SUB:S/$/!g/:S/^/ -e s!%%/:S/=/%%!/} \
+		${FILESDIR}/pwcheck.sh > ${PREFIX}/etc/rc.d/cyrus_pwcheck.sh
+	@${CHMOD} 755 ${PREFIX}/etc/rc.d/cyrus_pwcheck.sh
+	@${SED} ${RC_SCRIPTS_SUB:S/$/!g/:S/^/ -e s!%%/:S/=/%%!/} \
 		${FILESDIR}/saslauthd.sh > ${PREFIX}/etc/rc.d/saslauthd1.sh
 	@${CHMOD} 755 ${PREFIX}/etc/rc.d/saslauthd1.sh
+	@${SED} ${RC_SCRIPTS_SUB:S/$/!g/:S/^/ -e s!%%/:S/=/%%!/} \
+		${FILESDIR}/cyrus_sasl1 > ${PREFIX}/etc/rc.d/cyrus_sasl1
+	@${CHMOD} 755 ${PREFIX}/etc/rc.d/cyrus_sasl1
+	${INSTALL} -d -m 770 -o cyrus -g cyrus /var/pwcheck
 	${INSTALL} -d -m 770 -o cyrus -g cyrus /var/state/saslauthd1
 .if !defined(NOPORTDOCS)
 	@${MKDIR} ${DOCSDIR}
Index: distinfo
===================================================================
RCS file: /home/ncvs/ports/security/cyrus-sasl/distinfo,v
retrieving revision 1.9
diff -u -r1.9 distinfo
--- distinfo	26 Jun 2002 18:49:21 -0000	1.9
+++ distinfo	31 Oct 2002 16:14:22 -0000
@@ -1,4 +1,4 @@
-MD5 (cyrus-sasl-1.5.27.tar.gz) = 76ea426e2e2da3b8d2e3a43af5488f3b
-MD5 (sasl-1.5.27-ldap-ssl-filter-mysql-patch4.tgz) = 3e2b5cf7c5f8f0e8551f28a8d83391bb
+MD5 (cyrus-sasl-1.5.28.tar.gz) = 60710be040801e9aff7353563b636518
+MD5 (sasl-1.5.28-ldap-ssl-filter-mysql-patch.tgz) = ab54e054e6acea2f9795fd8c46c3ebe6
 MD5 (sasl_apop_patch.gz) = 6bf7a34b73d1c8d139d2269069d1ba4c
-MD5 (cyrus-sasl-1.5.27-ipv6-20020106.diff.gz) = b2956a084954a46ba2d751f56a80a275
+MD5 (cyrus-sasl-1.5.28-ipv6-20020106.diff.gz) = 5987181a53531a46b2aec88b9aea6f9a
Index: pkg-deinstall
===================================================================
RCS file: /home/ncvs/ports/security/cyrus-sasl/pkg-deinstall,v
retrieving revision 1.6
diff -u -r1.6 pkg-deinstall
--- pkg-deinstall	14 Aug 2002 18:39:45 -0000	1.6
+++ pkg-deinstall	4 Oct 2002 01:22:17 -0000
@@ -12,6 +12,32 @@
 
 SASLDB_NAME=${PKG_PREFIX}/etc/%%SASLDB%%
 
+remove_file()
+{
+	file=$1
+
+	if cmp -s ${file} ${file}.tmp; then
+		rm -f ${file}
+	fi
+	rm -f ${file}.tmp
+}
+
+delete_rc_conf_d() {
+	PWCHECK_CONF=${PKG_PREFIX}/etc/rc.conf.d/cyrus_pwcheck
+	SASLAUTHD_CONF=${PKG_PREFIX}/etc/rc.conf.d/saslauthd1   
+
+	if [ -f ${SASLAUTHD_CONF} ]; then
+		echo "saslauthd1_enable=%%ENABLE_SASLAUTHD%%" >> ${SASLAUTHD_CONF}.tmp
+		echo "saslauthd1_flags=\"-a pam\"" >> ${SASLAUTHD_CONF}.tmp
+		remove_file ${SASLAUTHD_CONF}
+	fi
+	if [ -f ${PWCHECK_CONF} ]; then
+		echo "cyrus_pwcheck_enable=%%ENABLE_PWCHECK%%" > ${PWCHECK_CONF}.tmp
+		echo "cyrus_pwcheck_program=${PKG_PREFIX}/sbin/%%PWCHECK%%" >> ${PWCHECK_CONF}.tmp
+		remove_file ${PWCHECK_CONF}
+	fi
+}
+
 # delete sasldb database
 
 delete_sasldb() {
@@ -39,16 +65,14 @@
 sendmail_conf() {
 	if [ -f ${PKG_PREFIX}/lib/sasl/Sendmail.conf ]; then
 		echo "pwcheck_method: %%PWCHECK_METHOD%%" > ${PKG_PREFIX}/lib/sasl/Sendmail.conf.tmp
-		if cmp -s ${PKG_PREFIX}/lib/sasl/Sendmail.conf ${PKG_PREFIX}/lib/sasl/Sendmail.conf.tmp; then
-			rm -f ${PKG_PREFIX}/lib/sasl/Sendmail.conf
-		fi
-		rm -f ${PKG_PREFIX}/lib/sasl/Sendmail.conf.tmp
+		remove_file ${PKG_PREFIX}/lib/sasl/Sendmail.conf
 	fi
 }
 
 case $2 in
 	DEINSTALL)
 		delete_sasldb
+		delete_rc_conf_d
 		sendmail_conf
 		;;
 	POST-DEINSTALL)
Index: pkg-install
===================================================================
RCS file: /home/ncvs/ports/security/cyrus-sasl/pkg-install,v
retrieving revision 1.10
diff -u -r1.10 pkg-install
--- pkg-install	14 Aug 2002 18:39:45 -0000	1.10
+++ pkg-install	4 Oct 2002 01:16:26 -0000
@@ -90,6 +90,23 @@
 	fi
 }
 
+create_rc_conf_d() {
+	PWCHECK_CONF=${PKG_PREFIX}/etc/rc.conf.d/cyrus_pwcheck
+	SASLAUTHD_CONF=${PKG_PREFIX}/etc/rc.conf.d/saslauthd1
+
+	if [ ! -d ${PKG_PREFIX}/etc/rc.conf.d ]; then
+		mkdir ${PKG_PREFIX}/etc/rc.conf.d
+	fi
+	if [ ! -f ${SASLAUTHD_CONF} ]; then
+		echo "saslauthd1_enable=%%ENABLE_SASLAUTHD%%" > ${SASLAUTHD_CONF}
+		echo "saslauthd1_flags=\"-a pam\"" >> ${SASLAUTHD_CONF}
+	fi
+	if [ ! -f ${PWCHECK_CONF} ]; then
+		echo "cyrus_pwcheck_enable=%%ENABLE_PWCHECK%%" > ${PWCHECK_CONF}
+		echo "cyrus_pwcheck_program=${PKG_PREFIX}/sbin/%%PWCHECK%%" >> ${PWCHECK_CONF}
+	fi
+}
+
 case $2 in
 	PRE-INSTALL)
 		create_user
@@ -97,6 +114,7 @@
 	POST-INSTALL)
 		if [ "${PKG_BATCH}" = "NO" ]; then
 			create_sasldb
+			create_rc_conf_d
 			sendmail_conf
 		fi
 		;;
Index: pkg-plist
===================================================================
RCS file: /home/ncvs/ports/security/cyrus-sasl/pkg-plist,v
retrieving revision 1.17
diff -u -r1.17 pkg-plist
--- pkg-plist	1 Sep 2002 16:38:33 -0000	1.17
+++ pkg-plist	3 Oct 2002 22:59:52 -0000
@@ -1,8 +1,9 @@
 @comment The following makes sure that the pwcheck and saslauthd
 @comment daemons are stopped before removing the files.
-@unexec if [ -f /var/run/pwcheck.pid ] ; then %D/etc/rc.d/pwcheck.sh stop ; echo " stopped." ; fi
+@unexec if [ -f /var/run/pwcheck.pid ] ; then %D/etc/rc.d/cyrus_pwcheck.sh stop ; echo " stopped." ; fi
 @unexec if [ -f /var/state/saslauthd1/mux.pid ] ; then %D/etc/rc.d/saslauthd1.sh stop ; echo " stopped." ; fi
-etc/rc.d/pwcheck.sh
+etc/rc.d/cyrus_pwcheck.sh
+etc/rc.d/cyrus_sasl1
 etc/rc.d/saslauthd1.sh
 include/sasl1/hmac-md5.h
 include/sasl1/md5.h
@@ -82,6 +83,7 @@
 %%PORTDOCS%%%%DOCSDIR%%/rfc2831.txt
 %%PORTDOCS%%%%DOCSDIR%%/gssapi.html
 %%PORTDOCS%%%%DOCSDIR%%/index.html
+%%PORTDOCS%%%%DOCSDIR%%/macosx.html
 %%PORTDOCS%%%%DOCSDIR%%/programming.html
 %%PORTDOCS%%%%DOCSDIR%%/sysadmin.html
 %%PORTDOCS%%@dirrm %%DOCSDIR%%
Index: files/cyrus_sasl1
===================================================================
RCS file: files/cyrus_sasl1
diff -N files/cyrus_sasl1
--- /dev/null	1 Jan 1970 00:00:00 -0000
+++ files/cyrus_sasl1	4 Oct 2002 01:39:56 -0000
@@ -0,0 +1,16 @@
+#!/bin/sh
+#
+# $FreeBSD$
+#
+
+# PROVIDE: sasl1
+# REQUIRE: DAEMON %%MYSQL_REQ%%
+# KEYWORD: FreeBSD
+#
+# NOTE for FreeBSD 5.0+:
+# If you want this script to start with the base rc scripts copy
+# cyrus_sasl1 to /etc/rc.d/cyrus_sasl1
+
+# This is a dummy dependancy, to ensure that daemons are run _before_
+# `sasl1' is available.
+
Index: files/patch-ab
===================================================================
RCS file: /home/ncvs/ports/security/cyrus-sasl/files/patch-ab,v
retrieving revision 1.14
diff -u -r1.14 patch-ab
--- files/patch-ab	18 Jun 2002 06:16:47 -0000	1.14
+++ files/patch-ab	18 Feb 2003 20:34:25 -0000
@@ -1,5 +1,5 @@
---- configure.in.orig	Wed May 22 20:49:46 2002
-+++ configure.in	Thu May 23 16:52:07 2002
+--- configure.in.orig	Tue Feb 18 13:18:11 2003
++++ configure.in	Tue Feb 18 14:34:11 2003
 @@ -66,8 +66,12 @@
  dnl check for -R, etc. switch
  CMU_GUESS_RUNPATH_SWITCH
@@ -24,37 +24,7 @@
  fi
  
  AM_CONDITIONAL(SAMPLE, test "$enable_sample" = yes)
-@@ -149,11 +151,13 @@
- 	AC_CHECK_HEADER(db.h,
- 			AC_CHECK_LIB(db-3, db_create, SASL_DB_LIB="-ldb-3";
- 			   dblib="berkeley",
-+			AC_CHECK_LIB(db3, db_create, SASL_DB_LIB="-ldb3";
-+			   dblib="berkeley",
- 			AC_CHECK_LIB(db, db_create, SASL_DB_LIB="-ldb";
- 			   dblib="berkeley",
- 			AC_CHECK_LIB(db, db_open, SASL_DB_LIB="-ldb"; 
- 			   dblib="berkeley",
--                        dblib="no"))),
-+                        dblib="no")))),
- 			dblib="no")
- 	;;
-   gdbm)
-@@ -175,11 +179,13 @@
- 	AC_CHECK_HEADER(db.h,
- 			AC_CHECK_LIB(db-3, db_create, SASL_DB_LIB="-ldb-3";
- 			   dblib="berkeley",
-+			AC_CHECK_LIB(db3, db_create, SASL_DB_LIB="-ldb3";
-+			   dblib="berkeley",
- 			AC_CHECK_LIB(db, db_create, SASL_DB_LIB="-ldb";
- 			   dblib="berkeley",
- 			AC_CHECK_LIB(db, db_open, SASL_DB_LIB="-ldb"; 
- 			   dblib="berkeley",
--                        dblib="no"))),
-+                        dblib="no")))),
- 			dblib="no")
- 	if test "$dblib" = no; then
- 	  dnl How about ndbm?
-@@ -229,6 +235,13 @@
+@@ -239,6 +241,13 @@
    berkeley)
      SASL_DB_BACKEND="db_${dblib}.lo"
      AC_DEFINE(SASL_BERKELEYDB)
@@ -68,25 +38,69 @@
      ;;
    *)
      AC_MSG_WARN([Disabling SASL authentication database support])
-@@ -534,12 +547,16 @@
+@@ -473,16 +482,40 @@
+     CPPFLAGS="$CPPFLAGS -I${with_des}/include"
+     LDFLAGS="$LDFLAGS -L${with_des}/lib"
    fi
+-  AC_CHECK_LIB(des, des_pcbc_encrypt, [LIB_DES="-ldes";
+-				       with_des=yes], with_des=no)
++
++  dnl check for openssl installing -lcrypto, then make vanilla check
++  AC_CHECK_LIB(crypto, des_cbc_encrypt, [
++      AC_CHECK_HEADER(openssl/des.h, [AC_DEFINE(WITH_SSL_DES)
++                                     LIB_DES="-lcrypto";
++                                     with_des=yes],
++                     with_des=no)],
++      with_des=no, $LIB_RSAREF)
++
++  dnl same test again, different symbol name
++  if test "$with_des" = no; then
++    AC_CHECK_LIB(crypto, DES_cbc_encrypt, [
++      AC_CHECK_HEADER(openssl/des.h, [AC_DEFINE(WITH_SSL_DES)
++                                     LIB_DES="-lcrypto";
++                                     with_des=yes],
++                     with_des=no)],
++      with_des=no, $LIB_RSAREF)
++  fi
++
++  if test "$with_des" = no; then
++    AC_CHECK_LIB(des, des_pcbc_encrypt, [LIB_DES="-ldes";
++				         with_des=yes], with_des=no)
++  fi
++
+   if test "$with_des" = no; then
+     AC_CHECK_LIB(des524, des_pcbc_encrypt, [LIB_DES="-ldes524";
+ 				       with_des=yes], with_des=no)
+   fi
++
+   if test "$with_des" = no; then
+     AC_CHECK_LIB(des425, des_pcbc_encrypt, [LIB_DES="-ldes425";
+ 				       with_des=yes], with_des=no)
+   fi
++
+   if test "$with_des" = no; then
+     dnl if openssl is around, we might be able to use that for des
+ 
+@@ -493,7 +526,7 @@
+                  LIB_RSAREF="-lRSAglue -lrsaref"; cmu_have_rsaref=yes,
+                  cmu_have_rsaref=no)
+ 
+-    AC_CHECK_LIB(crypto, des_pcbc_encrypt, 
++    AC_CHECK_LIB(crypto, des_cbc_encrypt, 
+ 	AC_CHECK_HEADER(openssl/des.h, [AC_DEFINE(WITH_SSL_DES)
+ 					LIB_DES="-lcrypto";
+ 					with_des=yes],
+@@ -502,10 +535,9 @@
+   fi
+ fi
+ 
+-dnl if test "$with_des" != no; then
+-dnl   AC_DEFINE(WITH_DES)
+-dnl  LIB_DES="-ldes"
+-dnl fi
++if test "$with_des" != no; then
++  AC_DEFINE(WITH_DES)
++fi
+ 
+ AC_SUBST(LIB_DES)
  
-   if test "$with_des" != no; then
-+    case "$host_os" in
-+	freebsd*)
-+	    COM_ERR="-lcom_err"
-+	    ;;
-+    esac
-     AC_CHECK_HEADER(krb.h,
--      AC_CHECK_LIB(krb, krb_mk_priv, COM_ERR="",
--	AC_CHECK_LIB(krb, krb_mk_priv, COM_ERR="-lcom_err",
--                     AC_WARN(No Kerberos V4 found); krb4=no, -ldes -lcom_err),
--        -ldes),
--      AC_WARN(No Kerberos V4 found); krb4=no)
-+      AC_CHECK_LIB(krb, krb_mk_priv,:,
-+                AC_WARN(No Kerberos V4 found); krb4=no,
-+		-ldes ${COM_ERR}),
-+      AC_WARN(No Kerberos V4 headers found); krb4=no)
-   else
-     AC_WARN(No DES library found for Kerberos V4 support)
-     krb4=no
Index: files/patch-plugins::gssapi.c
===================================================================
RCS file: files/patch-plugins::gssapi.c
diff -N files/patch-plugins::gssapi.c
--- files/patch-plugins::gssapi.c	22 Jan 2002 05:30:03 -0000	1.1
+++ /dev/null	1 Jan 1970 00:00:00 -0000
@@ -1,15 +0,0 @@
---- plugins/gssapi.c.orig	Fri Mar  9 23:56:46 2001
-+++ plugins/gssapi.c	Mon Jan 21 21:03:32 2002
-@@ -71,6 +71,12 @@
- #include <saslutil.h>
- #include <saslplug.h>
- 
-+#ifdef HAVE_UNISTD_H
-+#include <unistd.h>
-+#endif
-+
-+#include <errno.h>
-+
- #ifdef WIN32
- /* This must be after sasl.h */
- # include "saslgssapi.h"
Index: files/patch-saslauthd::Makefile.am
===================================================================
RCS file: /home/ncvs/ports/security/cyrus-sasl/files/patch-saslauthd::Makefile.am,v
retrieving revision 1.1
diff -u -r1.1 patch-saslauthd::Makefile.am
--- files/patch-saslauthd::Makefile.am	14 Aug 2002 18:39:46 -0000	1.1
+++ files/patch-saslauthd::Makefile.am	10 Sep 2002 06:26:56 -0000
@@ -1,11 +1,10 @@
---- saslauthd/Makefile.am.orig	Fri Mar 23 19:41:35 2001
-+++ saslauthd/Makefile.am	Tue Aug 13 13:57:10 2002
-@@ -2,7 +2,7 @@
- man_MANS	= saslauthd.8
- 
- saslauthd_SOURCES = saslauthd.c mechanisms.c globals.h mechanisms.h auth_dce.c auth_dce.h auth_getpwent.c auth_getpwent.h auth_krb4.c auth_krb4.h auth_pam.c auth_pam.h auth_rimap.c auth_rimap.h auth_shadow.c auth_shadow.h auth_sia.c auth_sia.h
--saslauthd_LDADD	= @SASL_KRB_LIB@
-+saslauthd_LDADD	= @SASL_KRB_LIB@ @LIB_PAM@ @LIB_CRYPT@
- 
+--- saslauthd/Makefile.am.orig	Thu Dec 20 20:31:19 2001
++++ saslauthd/Makefile.am	Tue Sep 10 01:26:07 2002
+@@ -7,5 +7,5 @@
  INCLUDES	= -I$(top_srcdir)/include
- EXTRA_DIST	= saslauthd.8
+ 
+ install-data-local:
+-	$(mkinstalldirs) $(DESTDIR)$(mandir)/cat8
+-	$(INSTALL_DATA) saslauthd.8 $(DESTDIR)$(mandir)/cat8/saslauthd.8
++	$(mkinstalldirs) $(DESTDIR)$(mandir)/man8
++	$(INSTALL_DATA) saslauthd.8 $(DESTDIR)$(mandir)/man8/saslauthd.8
Index: files/saslauthd.sh
===================================================================
RCS file: /home/ncvs/ports/security/cyrus-sasl/files/saslauthd.sh,v
retrieving revision 1.1
diff -u -r1.1 saslauthd.sh
--- files/saslauthd.sh	14 Aug 2002 18:39:46 -0000	1.1
+++ files/saslauthd.sh	4 Oct 2002 17:04:09 -0000
@@ -3,73 +3,124 @@
 # $FreeBSD: ports/security/cyrus-sasl/files/saslauthd.sh,v 1.1 2002/08/14 18:39:46 knu Exp $
 #
 
-action=$1
-
-PREFIX=%%PREFIX%%
-
-# Suck in the configuration variables.
-if [ -z "${source_rc_confs_defined}" ]; then
-        if [ -r /etc/defaults/rc.conf ]; then
-                . /etc/defaults/rc.conf
-                source_rc_confs
-        elif [ -r /etc/rc.conf ]; then
-                . /etc/rc.conf
-        fi
-fi
-
-# The following sasl_saslauthd_* variables may be defined in rc.conf
+# PROVIDE: saslauthd1
+# REQUIRE: DAEMON
+# BEFORE: mail imap
+# KEYWORD: FreeBSD shutdown
 #
-# 	sasl_saslauthd1_enable  - Set to YES to enable saslauthd
-#				 Default: %%ENABLESASLAUTHD%%
+# NOTE for FreeBSD 5.0+:
+# If you want this script to start with the base rc scripts
+# move saslauthd1.sh to /etc/rc.d/saslauthd1
+
+# Define the following saslauthd1_* variables in one of the following:
+#	/etc/rc.conf
+#	/etc/rc.conf.d/saslauthd1
+#	${prefix}/etc/rc.conf.d/saslauthd1
 #
-#	sasl_saslauthd1_program - Path to saslauthd program
-#				 Default: ${PREFIX}/sbin/saslauthd1
+#       saslauthd1_enable  - Set to YES to enable saslauthd
+#			     Default: %%ENABLE_SASLAUTHD%%
 #
-#	sasl_saslauthd1_flags   - Flags to saslauthd program
-#				 Default: -a pam
+#       saslauthd1_program - Path to saslauthd program
+#                            Default: ${prefix}/sbin/saslauthd1
+#
+#       saslauthd1_flags   - Flags to saslauthd program
+#                            Default: -a pam
 
-if [ -z "${sasl_saslauthd1_enable}" ]; then
-	sasl_saslauthd1_enable=%%ENABLESASLAUTHD%%
-fi
+prefix=%%PREFIX%%
 
-if [ -z "${sasl_saslauthd1_program}" ]; then
-	sasl_saslauthd1_program=${PREFIX}/sbin/saslauthd1
-fi
+if [ -f /etc/rc.subr ]; then
+	. /etc/rc.subr
 
-if [ -z "${sasl_saslauthd1_flags}" ]; then
-	sasl_saslauthd1_flags="-a pam"
-fi
+	name="saslauthd1"
+	rcvar=`set_rcvar`
+	command="${prefix}/sbin/${name}"
+	pidfile="/var/state/${name}/mux.pid"
+
+	# The below may be removed when load_local_rc_config is added to rc.subr
+
+	if [ -f ${prefix}/etc/rc.conf.d/"$name" ]; then
+		debug "Sourcing ${prefix}/etc/rc.conf.d/${name}"
+		. ${prefix}/etc/rc.conf.d/"$name"
+	fi
+
+	load_rc_config $name
+
+	if [ -z "${saslauthd1_enable}" ]; then
+		saslauthd1_enable=%%ENABLE_SASLAUTHD%%
+	fi
+
+	# The above may be removed when load_local_rc_config is added to rc.subr
+	#
+	#load_local_rc_config $name
+	run_rc_command "$1"
+else
+	# Suck in the configuration variables.
+	if [ -z "${source_rc_confs_defined}" ]; then
+		if [ -r /etc/defaults/rc.conf ]; then
+			. /etc/defaults/rc.conf
+			source_rc_confs
+		elif [ -r /etc/rc.conf ]; then
+			. /etc/rc.conf
+		fi
+	fi
 
-rc=0
+	if [ -f ${prefix}/etc/rc.conf.d/saslauthd1 ]; then
+		. ${prefix}/etc/rc.conf.d/saslauthd1
+	fi
+
+	if [ -n "${sasl_saslauthd1_enable}" ]; then
+		echo "sasl_saslauthd1_enable has been depreciated, use saslauthd1_enable instead"
+		saslauthd1_enable=$sasl_saslauthd1_enable
+	fi
+
+	if [ -z "${saslauthd1_enable}" ]; then
+		saslauthd1_enable=%%ENABLE_SASLAUTHD%%
+	fi
+
+	if [ -z "${saslauthd1_program}" ]; then
+		saslauthd1_program=${prefix}/sbin/saslauthd1
+	fi
+
+	if [ -n "${sasl_saslauthd1_flags}" ]; then
+        	echo "sasl_saslauthd1_flags has been depreciated, use saslauthd1_flags instead"
+        	saslauthd1_flags=$sasl_saslauthd1_flags
+	fi
+
+	if [ -z "${saslauthd1_flags}" ]; then
+		saslauthd1_flags="-a pam"
+	fi
 
-case "${sasl_saslauthd1_enable}" in
-    [Yy][Ee][Ss])
-	case "${action}" in
-
-	    start)
-		if [ -x ${sasl_saslauthd1_program} ] ; then
-		    ${sasl_saslauthd1_program} ${sasl_saslauthd1_flags} \
-			&& echo -n " saslauthd1"
-		fi
-		;;
+	rc=0
 
-	    stop)
-		if [ -r /var/state/saslauthd1/mux.pid ]; then
-		    kill `cat /var/state/saslauthd1/mux.pid` && \
-			echo -n " saslauthd1"
-		    rm /var/state/saslauthd1/mux.pid
-		fi
+	case "${saslauthd1_enable}" in
+	    [Yy][Ee][Ss])
+		case "${1}" in
+
+		    start)
+			if [ -x ${saslauthd1_program} ] ; then
+			    ${saslauthd1_program} ${saslauthd1_flags} \
+				&& echo -n " saslauthd1"
+			fi
+			;;
+
+		    stop)
+			if [ -r /var/state/saslauthd1/mux.pid ]; then
+			    kill `cat /var/state/saslauthd1/mux.pid` && \
+				echo -n " saslauthd1"
+			    rm /var/state/saslauthd1/mux.pid
+			fi
+			;;
+
+		    *)
+			echo "usage: $0 {start|stop}" 1>&2
+			rc=64
+			;;
+		esac
 		;;
-
 	    *)
-		echo "usage: $0 {start|stop}" 1>&2
-		rc=64
+		rc=0
 		;;
 	esac
-	;;
-    *)
-	rc=0
-	;;
-esac
 
-exit $rc
+	exit $rc
+fi
Index: scripts/configure.sasl
===================================================================
RCS file: /home/ncvs/ports/security/cyrus-sasl/scripts/configure.sasl,v
retrieving revision 1.14
diff -u -r1.14 configure.sasl
--- scripts/configure.sasl	22 Aug 2002 19:13:37 -0000	1.14
+++ scripts/configure.sasl	31 Oct 2002 19:23:03 -0000
@@ -93,7 +93,7 @@
 ${MKDIR} ${WRKDIRPREFIX}${REALCURDIR}
 exec > ${WRKDIRPREFIX}${REALCURDIR}/Makefile.inc
 
-echo "PREFIX=	${PREFIX}"
+echo "PREFIX=			${PREFIX}"
 
 while [ "$1" ]; do
 	case $1 in
@@ -133,6 +133,7 @@
 		\"MySQL\")
 			echo "LIB_DEPENDS+=	mysqlclient.10:\${PORTSDIR}/databases/mysql323-client"
 			echo "CONFIGURE_ARGS+=	--with-mysql=\${PREFIX}"
+			MYSQL_REQ=mysql
 			MSG=1
 			;;
 		\"OpenLDAP1\")
@@ -144,7 +145,9 @@
 			echo "LIB_DEPENDS+=	ldap.1:\${PORTSDIR}/net/openldap"
 			echo "LIB_DEPENDS+=	lber.1:\${PORTSDIR}/net/openldap"
 			echo "CONFIGURE_ARGS+=	--with-ldap=\${PREFIX}"
+			LDAP_REQ=ldap
 			OPENLDAP=1
+			MSG=1
 			;;
 		\"OpenLDAP2\")
 			if [ "$OPENLDAP" ]; then
@@ -155,22 +158,22 @@
 			echo "LIB_DEPENDS+=	ldap.2:\${PORTSDIR}/net/openldap2"
 			echo "LIB_DEPENDS+=	lber.2:\${PORTSDIR}/net/openldap2"
 			echo "CONFIGURE_ARGS+=	--with-ldap=\${PREFIX}"
+			LDAP_REQ=ldap
 			OPENLDAP=1
+			MSG=1
 			;;
 		\"PWCHECK\")
 			if [ "$PWCHECK" ]; then
 				echo "PWCHECK or PAMPWCHECK must be choosen seperately: Defaulting to PAMPWCHECK" > /dev/stderr
 			else
-				echo "PWCHECK_SUB+=	-e \"s;%%PWCHECK%%;pwcheck;g\""
-				PWCHECK=1
+				PWCHECK=pwcheck
 			fi
 			;;
 		\"PAMPWCHECK\")
 			if [ "$PWCHECK" ]; then
 				echo "PWCHECK or PAMPWCHECK must be choosen seperately: Defaulting to PWCHECK" > /dev/stderr
 			else
-				echo "PWCHECK_SUB+=	-e \"s;%%PWCHECK%%;pwcheck_pam;g\""
-				PWCHECK=1
+				PWCHECK=pwcheck_pam
 			fi
 			;;
 		\"SASLAUTHD\")
@@ -188,24 +191,35 @@
 	shift
 done
 
-if [ ! "${PWCHECK}" ]; then
-	echo "PWCHECK_SUB+=	-e \"s;%%PWCHECK%%;pwcheck;g\""
-fi
-
-if [ "$SASLAUTHD" ]; then
-	echo "PWCHECK_SUB+=	-e \"s;%%ENABLEPWCHECK%%;no;g\""
-	echo "PWCHECK_METHOD=	saslauthd"
-	echo "SASLAUTHD_SUB+=	-e \"s;%%ENABLESASLAUTHD%%;yes;g\""
+if [ "${SASLAUTHD}" ]; then
+	ENABLE_PWCHECK=no
+	PWCHECK_METHOD=saslauthd
+	ENABLE_SASLAUTHD=yes
+	if [ -z "${PWCHECK}" ]; then
+		PWCHECK=pwcheck
+	fi
 else
-	if [ "$PWCHECK" ]; then
-		echo "PWCHECK_SUB+=	-e \"s;%%ENABLEPWCHECK%%;yes;g\""
+	if [ "${PWCHECK}" ]; then
+		ENABLE_PWCHECK=yes
 	else
-		echo "PWCHECK_SUB+=	-e \"s;%%ENABLEPWCHECK%%;no;g\""
+		ENABLE_PWCHECK=no
+		PWCHECK=pwcheck
 	fi
-	echo "PWCHECK_METHOD+=	pwcheck"
-	echo "SASLAUTHD_SUB+=	-e \"s;%%ENABLESASLAUTHD%%;no;g\""
+	PWCHECK_METHOD=pwcheck
+	ENABLE_SASLAUTHD=no
 fi
 
+echo "PWCHECK=		${PWCHECK}"
+echo "PWCHECK_METHOD=		${PWCHECK_METHOD}"
+echo "ENABLE_PWCHECK=		${ENABLE_PWCHECK}"
+echo "ENABLE_SASLAUTHD=	${ENABLE_SASLAUTHD}"
+
+echo "RC_SCRIPTS_SUB+=	PREFIX=\${PREFIX} \\"
+echo "			PWCHECK=\${PWCHECK} \\"
+echo "			ENABLE_PWCHECK=\${ENABLE_PWCHECK} \\"
+echo "			ENABLE_SASLAUTHD=\${ENABLE_SASLAUTHD} \\"
+echo "			MYSQL_REQ=${MYSQL_REQ}"
+
 if [ ! "${DEFJAVA}" ]; then
 	echo "PLIST_SUB+=	JAVASASL=\"@comment \""
 fi
@@ -214,6 +228,16 @@
 	echo "SASLDB_NAME=	sasldb.db"
 fi
 
-if [ "$OPENLDAP" ]; then
-	echo "LDAP_MYSQL_MSG=	\"See sysadmin.html in the Cyrus-SASL docs directory for informaion on using LDAP or MySQL for authentication.\""
+if [ "${MSG}" ]; then
+	if [ -n "${LDAP_REQ}" ]; then
+		METHOD="LDAP"
+
+		if [ -n "${MYSQL_REQ}" ]; then
+			METHOD="LDAP or MySQL"
+		fi
+	elif [ -n "${MYSQL_REQ}" ]; then
+		METHOD="MySQL"
+	fi
+
+	echo "LDAP_MYSQL_MSG=	\"See sysadmin.html in the Cyrus-SASL docs directory for informaion on using ${METHOD} for authentication.\""
 fi
>Release-Note:
>Audit-Trail:
State-Changed-From-To: open->feedback 
State-Changed-By: edwin 
State-Changed-When: Sat Feb 22 22:52:17 PST 2003 
State-Changed-Why:  
[~/ports/security/cyrus-sasl] edwin@ref5>MASTER_SITE_OVERRIDE=1 make fetch 

From: "Scot Hetzel" <hetzels@westbend.net>
To: <edwin@FreeBSD.org>,
	"FreeBSD-GNATS" <FreeBSD-gnats-submit@FreeBSD.org>
Cc:  
Subject: Re: ports/48442: security/cyrus-sasl: Bento fails to build libkerberos + Upgrade
Date: Mon, 24 Feb 2003 15:39:17 -0600

 From: "Edwin Groothuis" <edwin@FreeBSD.org>
 > [~/ports/security/cyrus-sasl] edwin@ref5>MASTER_SITE_OVERRIDE=1 make fetch
 > >> sasl-1.5.28-ldap-ssl-filter-mysql-patch.tgz doesn't seem to exist in
 /home/edwin/ports/distfiles/.
 > >> Attempting to fetch from http://www.surf.org.uk/downloads/.
 > Receiving sasl-1.5.28-ldap-ssl-filter-mysql-patch (9841 bytes): 100%
 > 9841 bytes transferred in 0.3 seconds (31.36 kBps)
 > [~/ports/security/cyrus-sasl] edwin@ref5>make checksum
 > >> Checksum OK for cyrus-sasl-1.5.28.tar.gz.
 > >> Checksum mismatch for sasl-1.5.28-ldap-ssl-filter-mysql-patch.tgz.
 > >> Checksum OK for sasl_apop_patch.gz.
 > >> Checksum OK for cyrus-sasl-1.5.28-ipv6-20020106.diff.gz.
 >
 >
 > Can you please verify that file?
 >
 The file at surf.org is missing a patch to correct a SIG 11 problem when
 alias_deref is not defined in imapd.conf.  I have notified Simon of the
 problem, and hopefully he'll update the patch at his website.
 
 Scot
 
 diff -ruN ldap-mysql_sasl-1.5.28.orig/ChangeLog
 ldap-mysql_sasl-1.5.28/ChangeLog
 --- ldap-mysql_sasl-1.5.28.orig/ChangeLog       Thu Oct 31 09:56:55 2002
 +++ ldap-mysql_sasl-1.5.28/ChangeLog    Mon Sep  9 23:30:34 2002
 @@ -1,9 +1,3 @@
 -31-10-2002 - Scot Hetzel
 -
 -  If ldap_alias_deref wasn't defined in the imapd.conf file, the check
 -  would cause a sig 11 due to a null pointer was assigned to 'alias_deref'
 -  in lib/checkpw.c.  Fix provided by:  Thomas Klein <gourdin@gcu-squad.org>
 -
  09-09-2002 - Scot Hetzel
 
    Update to patch against 1.5.28
 diff -ruN ldap-mysql_sasl-1.5.28.orig/sasl-ldap+mysql.patch
 ldap-mysql_sasl-1.5.28/sasl-ldap+mysql.patch
 --- ldap-mysql_sasl-1.5.28.orig/sasl-ldap+mysql.patch   Thu Oct 31 09:53:23
 2002
 +++ ldap-mysql_sasl-1.5.28/sasl-ldap+mysql.patch        Mon Sep  9 23:50:06
 2002
 @@ -785,11 +785,11 @@
  +
  +  if (!alias_deref || *alias_deref == 'n' || *alias_deref =='N')
  +     { ldap_deref=LDAP_DEREF_NEVER; }
 -+  else if (*alias_deref == 's' || *alias_deref =='S')
 ++  if (*alias_deref == 's' || *alias_deref =='S')
  +     { ldap_deref=LDAP_DEREF_SEARCHING; }
 -+  else if (*alias_deref == 'f' || *alias_deref =='F')
 ++  if (*alias_deref == 'f' || *alias_deref =='F')
  +     { ldap_deref=LDAP_DEREF_FINDING; }
 -+  else if (*alias_deref == 'a' || *alias_deref =='A')
 ++  if (*alias_deref == 'a' || *alias_deref =='A')
  +     { ldap_deref=LDAP_DEREF_ALWAYS; }
  +  /* test for ssl mode */
  +  /* this will only work with openldap > v2
 
 

From: "Scot Hetzel" <hetzels@westbend.net>
To: "FreeBSD-GNATS" <FreeBSD-gnats-submit@FreeBSD.ORG>,
	<edwin@FreeBSD.ORG>
Cc:  
Subject: Re: ports/48442: security/cyrus-sasl: Bento fails to build libkerberos + Upgrade
Date: Mon, 24 Feb 2003 18:12:47 -0600

 Simon at surf.org has uploaded the corrected
 sasl-1.5.28-ldap-ssl-filter-mysql-patch.tgz file.  It now has an md5 of
 1cb8cd37573b6baa91339bcef2912e1a.  You'll need to use makesum to update
 distinfo.
 
 Scot
 

From: patrick <patrick@cookie.monster.org>
To: freebsd-gnats-submit@FreeBSD.org, hetzels@westbend.net
Cc:  
Subject: Re: ports/48442: security/cyrus-sasl: Bento fails to build libkerberos + Upgrade
Date: Tue, 25 Feb 2003 17:02:47 +0100

 This was also mistakenly submitted to PR ports/3671.
 
 I cvsupped to 1.5.28 and still get errors on FreeBSD 4.8-PRELEASE
 
 # New ports collection makefile for:    cyrus-sasl
 # Date created:                         Nov 1 1999
 # Whom:                                 hetzels@westbend.net
 #
 # $FreeBSD: ports/security/cyrus-sasl/Makefile,v 1.48 2003/02/21 
 13:26:42 knu Exp $
 #
 
 PORTNAME=       cyrus-sasl
 PORTVERSION=    1.5.28
 
 ....
 
 FreeBSD sco 4.8-PRERELEASE FreeBSD 4.8-PRERELEASE #1: Fri Feb 21 
 15:02:50 CET 2003     pine@sco:/usr/obj/usr/src/sys/SCO  i386
 
 ...
 
 creating libdigestmd5.la
 (cd .libs && rm -f libdigestmd5.la && ln -s ../libdigestmd5.la 
 libdigestmd5.la)
 /bin/sh ../libtool --mode=compile cc -DHAVE_CONFIG_H -I. -I. -I.. 
 -I../include  -I/usr/local/includee/db3 -I/usr/include/openssl  
 -I/usr/local/include  -Wall -W -O -pipe -c kerberos4.c
 rm -f .libs/kerberos4.lo
 cc -DHAVE_CONFIG_H -I. -I. -I.. -I../include -I/usr/local/include/db3 
 -I/usr/include/openssl -I/usr//local/include -Wall -W -O -pipe -c 
 kerberos4.c  -fPIC -DPIC -o .libs/kerberos4.lo
 kerberos4.c:731: unterminated macro call
 kerberos4.c:1402: warning: preprocessing directive not recognized 
 within macro arg
 kerberos4.c:1402: warning: preprocessing directive not recognized 
 within macro arg
 kerberos4.c:730: unterminated `#if' conditional
 In file included from /usr/include/krb.h:355,
                   from kerberos4.c:48:
 /usr/include/krb-protos.h:182: warning: `struct des_ks_struct' declared 
 inside parameter list
 /usr/include/krb-protos.h:182: warning: its scope is only this 
 definition or declaration, which is pprobably not what you want.
 /usr/include/krb-protos.h:455: warning: `struct des_ks_struct' declared 
 inside parameter list
 /usr/include/krb-protos.h:533: warning: `struct des_ks_struct' declared 
 inside parameter list
 /usr/include/krb-protos.h:573: warning: `struct des_ks_struct' declared 
 inside parameter list
 /usr/include/krb-protos.h:589: warning: `struct des_ks_struct' declared 
 inside parameter list
 kerberos4.c: In function `privacy_encode':
 kerberos4.c:195: incompatible type for argument 4 of `krb_mk_priv'
 kerberos4.c:195: warning: passing arg 6 of `krb_mk_priv' from 
 incompatible pointer type
 kerberos4.c:195: warning: passing arg 7 of `krb_mk_priv' from 
 incompatible pointer type
 kerberos4.c: In function `privacy_decode':
 kerberos4.c:279: incompatible type for argument 3 of `krb_rd_priv'
 kerberos4.c:279: warning: passing arg 5 of `krb_rd_priv' from 
 incompatible pointer type
 kerberos4.c:279: warning: passing arg 6 of `krb_rd_priv' from 
 incompatible pointer type
 kerberos4.c: In function `integrity_encode':
 kerberos4.c:344: warning: passing arg 5 of `krb_mk_safe' from 
 incompatible pointer type
 kerberos4.c:344: warning: passing arg 6 of `krb_mk_safe' from 
 incompatible pointer type
 kerberos4.c: In function `integrity_decode':
 kerberos4.c:426: warning: passing arg 4 of `krb_rd_safe' from 
 incompatible pointer type
 kerberos4.c:426: warning: passing arg 5 of `krb_rd_safe' from 
 incompatible pointer type
 kerberos4.c: In function `server_continue_step':
 kerberos4.c:733: undefined or invalid # directive
 kerberos4.c:736: undefined or invalid # directive
 kerberos4.c:740: warning: passing arg 1 of `DES_pcbc_encrypt' from 
 incompatible pointer type
 kerberos4.c:740: warning: passing arg 2 of `DES_pcbc_encrypt' from 
 incompatible pointer type
 kerberos4.c:740: syntax error before `;'
 kerberos4.c:742: syntax error before `;'
 kerberos4.c:712: warning: `testnum' might be used uninitialized in this 
 function
 kerberos4.c: At top level:
 kerberos4.c:870: syntax error before `)'
 kerberos4.c:871: invalid lvalue in unary `&'
 kerberos4.c:871: initializer element is not constant
 kerberos4.c:871: (near initialization for `plugins[0].mech_name')
 kerberos4.c:873: syntax error before `)'
 kerberos4.c:867: warning: array `plugins' assumed to have one element
 kerberos4.c:503: warning: `server_start' defined but not used
 kerberos4.c:512: warning: `dispose' defined but not used
 kerberos4.c:521: warning: `mech_free' defined but not used
 kerberos4.c:560: warning: `server_continue_step' defined but not used
 *** Error code 1
 
 Stop in /usr/ports/security/cyrus-sasl/work/cyrus-sasl-1.5.28/plugins.
 *** Error code 1
 
 Stop in /usr/ports/security/cyrus-sasl/work/cyrus-sasl-1.5.28.
 *** Error code 1
 
 Stop in /usr/ports/security/cyrus-sasl/work/cyrus-sasl-1.5.28.
 *** Error code 1
 
 Stop in /usr/ports/security/cyrus-sasl.
 *** Error code 1
 
 Stop in /usr/ports/security/cyrus-sasl.
 sco#
 
State-Changed-From-To: feedback->closed 
State-Changed-By: edwin 
State-Changed-When: Wed Feb 26 03:29:00 PST 2003 
State-Changed-Why:  
Commited, thanks! 

http://www.freebsd.org/cgi/query-pr.cgi?pr=48442 

From: "Scot Hetzel" <hetzels@westbend.net>
To: "patrick" <patrick@cookie.monster.org>,
	<freebsd-gnats-submit@FreeBSD.org>
Cc: <edwin@FreeBSD.org>
Subject: Re: ports/48442: security/cyrus-sasl: Bento fails to build libkerberos + Upgrade
Date: Thu, 27 Feb 2003 12:26:37 -0600

 From: "patrick" <patrick@cookie.monster.org>
 > This was also mistakenly submitted to PR ports/3671.
 >
 > I cvsupped to 1.5.28 and still get errors on FreeBSD 4.8-PRELEASE
 >
 :
 > /bin/sh ../libtool --mode=compile cc -DHAVE_CONFIG_H -I. -I. -I..
 > -I../include  -I/usr/local/includee/db3 -I/usr/include/openssl
 > -I/usr/local/include  -Wall -W -O -pipe -c kerberos4.c
 > rm -f .libs/kerberos4.lo
 > cc -DHAVE_CONFIG_H -I. -I. -I.. -I../include -I/usr/local/include/db3
 > -I/usr/include/openssl -I/usr//local/include -Wall -W -O -pipe -c
 > kerberos4.c  -fPIC -DPIC -o .libs/kerberos4.lo
 > kerberos4.c:731: unterminated macro call
 > kerberos4.c:1402: warning: preprocessing directive not recognized
 > within macro arg
 > kerberos4.c:1402: warning: preprocessing directive not recognized
 > within macro arg
 > kerberos4.c:730: unterminated `#if' conditional
 > In file included from /usr/include/krb.h:355,
 >                   from kerberos4.c:48:
 
 This problem is caused by the OpenSSL upgrade in 4.8, as the
 des_pcbc_encrypt function was changed to a macro, and a #if .. #else ..
 #endif, was being used to conditionalize the variable type used in the
 function..
 
 A fix for this problem has been submitted to PR 48731.
     http://www.freebsd.org/cgi/query-pr.cgi?pr=48731
 
 Scot
 

From: Emil Sit <sit@MIT.EDU>
To: freebsd-gnats-submit@FreeBSD.org, hetzels@westbend.net
Cc:  
Subject: Re: ports/48442: security/cyrus-sasl: Bento fails to build libkerberos + Upgrade
Date: Thu, 17 Apr 2003 13:51:57 -0400

 It looks to me libkerberos is still not built (at least on 4.8), see
 e.g.:
 
 http://bento.freebsd.org/errorlogs/i386-4-full-logs/cyrus-sasl-1.5.28.log.bz2
 http://bento.freebsd.org/errorlogs/i386-4-full-logs/cyrus-sasl-2.1.12.log.bz2
 
     checking for DES_cbc_encrypt in -lcrypto... yes
     checking for openssl/des.h... yes
     checking DIGEST-MD5... enabled
     checking KERBEROS_V4... disabled
 
 There are still references to -ldes that fail on 4.8-RELEASE.
 
 -- 
 Emil Sit / MIT: LCS PDOS, SIPB, OLC / http://web.mit.edu/sit/www/
>Unformatted:
 >> sasl-1.5.28-ldap-ssl-filter-mysql-patch.tgz doesn't seem to exist in /home/edwin/ports/distfiles/. 
 >> Attempting to fetch from http://www.surf.org.uk/downloads/. 
 Receiving sasl-1.5.28-ldap-ssl-filter-mysql-patch (9841 bytes): 100% 
 9841 bytes transferred in 0.3 seconds (31.36 kBps) 
 [~/ports/security/cyrus-sasl] edwin@ref5>make checksum 
 >> Checksum OK for cyrus-sasl-1.5.28.tar.gz. 
 >> Checksum mismatch for sasl-1.5.28-ldap-ssl-filter-mysql-patch.tgz. 
 >> Checksum OK for sasl_apop_patch.gz. 
 >> Checksum OK for cyrus-sasl-1.5.28-ipv6-20020106.diff.gz. 
 
 
 Can you please verify that file? 
 
 
 
 Responsible-Changed-From-To: freebsd-ports-bugs->edwin 
 Responsible-Changed-By: edwin 
 Responsible-Changed-When: Sat Feb 22 22:52:17 PST 2003 
 Responsible-Changed-Why:  
 I'll handle it 
 
 http://www.freebsd.org/cgi/query-pr.cgi?pr=48442 

Index: files/pwcheck.sh
===================================================================
RCS file: /home/ncvs/ports/security/cyrus-sasl/files/pwcheck.sh,v
retrieving revision 1.5
diff -u -r1.5 pwcheck.sh
--- files/pwcheck.sh	14 Aug 2002 18:39:46 -0000	1.5
+++ files/pwcheck.sh	4 Oct 2002 17:03:53 -0000
@@ -3,64 +3,105 @@
 # $FreeBSD: ports/security/cyrus-sasl/files/pwcheck.sh,v 1.5 2002/08/14 18:39:46 knu Exp $
 #
 
-action=$1
-
-PREFIX=%%PREFIX%%
-
-# Suck in the configuration variables.
-if [ -z "${source_rc_confs_defined}" ]; then
-        if [ -r /etc/defaults/rc.conf ]; then
-                . /etc/defaults/rc.conf
-                source_rc_confs
-        elif [ -r /etc/rc.conf ]; then
-                . /etc/rc.conf
-        fi
-fi
-
-# The following sasl_pwcheck_* variables may be defined in rc.conf
+# PROVIDE: cyrus_pwcheck
+# REQUIRE: DAEMON
+# BEFORE: mail imap
+# KEYWORD: FreeBSD shutdown
 #
-# 	sasl_pwcheck_enable  -	Set to YES to enable pwcheck
-#				Default: %%ENABLEPWCHECK%%
+# NOTE for FreeBSD 5.0+:
+# If you want this script to start with the base rc scripts
+# move cyrus_pwcheck.sh to /etc/rc.d/cyrus_pwcheck
+
+# Define the following cyrus_pwcheck_* variables in one of the following:
+#       /etc/rc.conf
+#       /etc/rc.conf.d/pwcheck
+#       ${prefix}/etc/rc.conf.d/pwcheck
 #
-#	sasl_pwcheck_program -	Path to pwcheck program (pwcheck/pwcheck_pam)
-#				Default: ${PREFIX}/sbin/%%PWCHECK%%
-
-if [ -z "${sasl_pwcheck_enable}" ] ; then
-	sasl_pwcheck_enable=%%ENABLEPWCHECK%%
-fi
+#       cyrus_pwcheck_enable  - Set to YES to enable pwcheck
+#				Default: %%ENABLE_PWCHECK%%
+#
+#       cyrus_pwcheck_program - Path to pwcheck program (pwcheck/pwcheck_pam)
+#				Default: ${prefix}/sbin/%%PWCHECK%%
 
-if [ -z "${sasl_pwcheck_program}" ]; then
-	sasl_pwcheck_program=${PREFIX}/sbin/%%PWCHECK%%
-fi
+prefix=%%PREFIX%%
 
-rc=0
+if [ -f /etc/rc.subr ]; then
+	. /etc/rc.subr
 
-case "${sasl_pwcheck_enable}" in
-    [Yy][Ee][Ss])
-	case "${action}" in
-
-	    start)
-		if [ -x ${sasl_pwcheck_program} ] ; then
-		    ${sasl_pwcheck_program} && echo -n " pwcheck"
+	name="cyrus_pwcheck"
+	rcvar=`set_rcvar`
+	command=${prefix}/sbin/%%PWCHECK%%
+	pidfile="/var/run/pwcheck.pid"
+
+	# The below may be removed when load_local_rc_config is added to rc.subr
+	
+	if [ -f ${prefix}/etc/rc.conf.d/"$name" ]; then
+        	debug "Sourcing ${prefix}/etc/rc.conf.d/${name}"
+        	. ${prefix}/etc/rc.conf.d/"$name"
+	fi
+
+	load_rc_config $name
+
+	if [ -z "${cyrus_pwcheck_enable}" ] ; then
+        	cyrus_pwcheck_enable=%%ENABLE_PWCHECK%%
+	fi
+
+	# The above may be removed when load_local_rc_config is added to rc.subr
+	#
+	# load_local_rc_config $name
+	run_rc_command "$1"
+else
+	# Suck in the configuration variables.
+	if [ -z "${source_rc_confs_defined}" ]; then
+		if [ -r /etc/defaults/rc.conf ]; then
+			. /etc/defaults/rc.conf
+			source_rc_confs
+		elif [ -r /etc/rc.conf ]; then
+			. /etc/rc.conf
 		fi
-		;;
+	fi
 
-	    stop)
-		if [ -r /var/run/pwcheck.pid ]; then
-		    kill `cat /var/run/pwcheck.pid` && echo -n " pwcheck"
-		    rm /var/run/pwcheck.pid
-		fi
-		;;
+	if [ -f ${prefix}/etc/rc.conf.d/cyrus_pwcheck" ]; then
+		. ${prefix}/etc/rc.conf.d/cyrus_pwcheck}"
+	fi
+
+	if [ -z "${cyrus_pwcheck_enable}" ] ; then
+		cyrus_pwcheck_enable=%%ENABLE_PWCHECK%%
+	fi
+
+	if [ -z "${cyrus_pwcheck_program}" ]; then
+		cyrus_pwcheck_program=${prefix}/sbin/%%PWCHECK%%
+	fi
+
+	rc=0
 
+	case "${cyrus_pwcheck_enable}" in
+	    [Yy][Ee][Ss])
+		case "${action}" in
+
+		    start)
+			if [ -x ${cyrus_pwcheck_program} ] ; then
+			    ${cyrus_pwcheck_program} && echo -n " cyrus_pwcheck"
+			fi
+			;;
+
+		    stop)
+			if [ -r /var/run/pwcheck.pid ]; then
+			    kill `cat /var/run/pwcheck.pid` && echo -n " cyrus_pwcheck"
+			    rm /var/run/pwcheck.pid
+			fi
+			;;
+
+		    *)
+			echo "usage: $0 {start|stop}" 1>&2
+			rc=64
+			;;
+		esac
+		;;
 	    *)
-		echo "usage: $0 {start|stop}" 1>&2
-		rc=64
+		rc=0
 		;;
 	esac
-	;;
-    *)
-	rc=0
-	;;
-esac
 
-exit $rc
+	exit $rc
+fi